import { transformError as sdkTransformError } from '@wix/sdk-runtime/transform-error';
import { renameKeysFromSDKRequestToRESTRequest, renameKeysFromRESTResponseToSDKResponse, } from '@wix/sdk-runtime/rename-all-nested-keys';
import * as ambassadorWixEventsScheduleV1ScheduleItem from './events-schedule-v1-schedule-item-schedule-bookmarks.http.js';
export var ScheduleStatus;
(function (ScheduleStatus) {
    /** Item is scheduled for a future date. */
    ScheduleStatus["SCHEDULED"] = "SCHEDULED";
    /** Item is canceled. */
    ScheduleStatus["CANCELED"] = "CANCELED";
})(ScheduleStatus || (ScheduleStatus = {}));
export var StateFilter;
(function (StateFilter) {
    /** Schedule item is published. */
    StateFilter["PUBLISHED"] = "PUBLISHED";
    /** Schedule item is in draft. */
    StateFilter["DRAFT"] = "DRAFT";
    /** Schedule item is visible to the event's guests. */
    StateFilter["VISIBLE"] = "VISIBLE";
    /** Schedule item is hidden to the event's guests. */
    StateFilter["HIDDEN"] = "HIDDEN";
})(StateFilter || (StateFilter = {}));
export var SortOrder;
(function (SortOrder) {
    SortOrder["ASC"] = "ASC";
    SortOrder["DESC"] = "DESC";
})(SortOrder || (SortOrder = {}));
/**
 * Retrieves a list of bookmarked schedule items for a current member.
 * @param eventId - Event ID to which the schedule item belongs.
 * @public
 * @requiredField eventId
 * @permissionId WIX_EVENTS.READ_AGENDA_BOOKMARKS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @applicableIdentity MEMBER
 * @fqn wix.events.schedule.BookmarkManagement.ListBookmarks
 */
export async function listBookmarks(eventId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({ eventId: eventId });
    const reqOpts = ambassadorWixEventsScheduleV1ScheduleItem.listBookmarks(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { eventId: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['eventId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Bookmarks a schedule item for a current member.
 * @param itemId - Schedule item ID.
 * @param eventId - Event ID to which the schedule item belongs.
 * @public
 * @requiredField eventId
 * @requiredField itemId
 * @permissionId WIX_EVENTS.MANAGE_AGENDA_BOOKMARKS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @applicableIdentity MEMBER
 * @fqn wix.events.schedule.BookmarkManagement.CreateBookmark
 */
export async function createBookmark(itemId, eventId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        itemId: itemId,
        eventId: eventId,
    });
    const reqOpts = ambassadorWixEventsScheduleV1ScheduleItem.createBookmark(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { itemId: '$[0]', eventId: '$[1]' },
            singleArgumentUnchanged: false,
        }, ['itemId', 'eventId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Removes a schedule item bookmark for a current member.
 * @param itemId - Schedule item ID.
 * @param eventId - Event ID to which the schedule item belongs.
 * @public
 * @requiredField eventId
 * @requiredField itemId
 * @permissionId WIX_EVENTS.MANAGE_AGENDA_BOOKMARKS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @applicableIdentity MEMBER
 * @fqn wix.events.schedule.BookmarkManagement.DeleteBookmark
 */
export async function deleteBookmark(itemId, eventId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        itemId: itemId,
        eventId: eventId,
    });
    const reqOpts = ambassadorWixEventsScheduleV1ScheduleItem.deleteBookmark(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { itemId: '$[0]', eventId: '$[1]' },
            singleArgumentUnchanged: false,
        }, ['itemId', 'eventId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
//# sourceMappingURL=events-schedule-v1-schedule-item-schedule-bookmarks.universal.js.map